==========
OASIS_stat
==========


.. image:: https://img.shields.io/pypi/v/oasis_stat.svg
        :target: https://pypi.python.org/pypi/oasis_stat

.. image:: https://readthedocs.org/projects/oasis-stat/badge/?version=latest
        :target: https://oasis-stat.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




OASIS (Optimized Adaptive Statistic for Inferring Structure) statistical test for interpretable analysis of contingency tables from https://www.pnas.org/doi/10.1073/pnas.2304671121.
Utilized in SPLASH https://github.com/refresh-bio/SPLASH for reference-free genomic inference https://www.cell.com/cell/fulltext/S0092-8674(23)01179-0. 


* Installable via pip: `pip install oasis_stat`
* Free software: MIT license
* Documentation: https://oasis-stat.readthedocs.io.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
